/**
 * Routes for the Vue router.
 *
 * Part of the basebox sample TODO app.
 * https://basebox.io
 */

import {loggedIn, showError, storeInit } from "../store";
import { createRouter, createWebHistory } from 'vue-router'
import HomeView from '../views/HomeView.vue'
import { objectToQueryString } from "../util/net";
import { callbackPath, getOidcUserManager } from "../util/oidc";

const router = createRouter({
  history: createWebHistory(import.meta.env.BASE_URL),
  routes: [
    {
      path: '/',
      name: 'home',
      component: HomeView
    },
    {
      path: '/about',
      name: 'about',
      // route level code-splitting
      // this generates a separate chunk (About.[hash].js) for this route
      // which is lazy-loaded when the route is visited.
      component: () => import('../views/AboutView.vue')
    },
    {
      path: '/lists',
      name: 'lists',
      component: () => import('../components/Lists.vue')
    },
  ]
})

router.beforeEach(async (to, from) => {

  /* catch OIDC callback */
  if (to.path === callbackPath) {
    console.info("OIDC: got OIDC callback request to ", to);
    const userMgr = getOidcUserManager();
    try {
      const user = await userMgr.signinRedirectCallback(location.origin + to.fullPath);
      console.info("OIDC: login complete, user: ", user);
      storeInit(user);
    } catch (err) {
      console.error("OIDC: Error handling signin callback: ", err);   
      showError("The login process failed: " + err);
    }
    /* redirect to home page */
    return {name: 'home'};
  }

  /* if no user is logged in, we redirect to the home page */
  if (!loggedIn() && to.path.length > 1 && to.path !== "/about") {
    return {name: 'home'};
  }

});

export default router
